 /*
   Copyright (c) 2014-2016 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#include "hal.h"
#include "power.h"

HAL_SObj_t HAL_SObj;

void HAL_sinit()
{
	int i,j;
	DIO_sinit(); // ok to call multiple times
	for(i=0; i<HAL_NUM_DIN_CHANNELS; i++)
	{
		HAL_SObj.inPortHandles[i] = DIO_init(&HAL_SObj.inPortObjs[i],sizeof(HAL_SObj.inPortObjs[i]));
	}
	for(i=0; i<HAL_NUM_DOUT_CHANNELS; i++)
	{
		HAL_SObj.outPortHandles[i] = DIO_init(&HAL_SObj.outPortObjs[i],sizeof(HAL_SObj.outPortObjs[i]));
	}

	PWM_sinit();
	for(i=0; i<HAL_NUM_PWM_CHANNELS; i++)
	{
		HAL_SObj.pwmHandles[i] = PWM_init(&HAL_SObj.pwmObjs[i],sizeof(HAL_SObj.pwmObjs[i]));
	}

	QEP_sinit();
	for(i=0; i<HAL_NUM_QEP_CHANNELS; i++)
	{
		HAL_SObj.qepHandles[i] = QEP_init(&HAL_SObj.qepObjs[i],sizeof(HAL_SObj.qepObjs[i]));
	}

	SPI_sinit();
	for(i=0; i<HAL_NUM_SPI_CHANNELS; i++)
	{
		HAL_SObj.spiHandles[i] = SPI_init(&HAL_SObj.spiObjs[i],sizeof(HAL_SObj.spiObjs[i]));
	}

	AIN_sinit();
	for(i=0; i<HAL_NUM_ADCS; i++)
	{
		HAL_SObj.aInHandle[i] = AIN_init(&HAL_SObj.aInObjs[i],sizeof(HAL_SObj.aInObjs[i]));
		for(j=0; j<HAL_NUM_CHANNELS_PER_ADC; j++)
		{
			HAL_SObj.aInScale[i][j] = 1.0;
			HAL_SObj.aInOffset[i][j] = 0.0;
		}
	}
}

void HAL_configure()
{
    PWR_unregisterAllPwmChannels();
}

void HAL_setupDigitalOut(uint16_t aChannel, uint16_t aResourceNumber, bool aInitialValue)
{
#if (HAL_NUM_DOUT_CHANNELS > 0)
    PLX_ASSERT(aChannel < HAL_NUM_DOUT_CHANNELS);
#endif
	DIO_configureOut(HAL_SObj.outPortHandles[aChannel], aResourceNumber, aInitialValue);
}

void HAL_setupDigitalIn(uint16_t aChannel, uint16_t aResourceNumber)
{
#if (HAL_NUM_DIN_CHANNELS > 0)
    PLX_ASSERT(aChannel < HAL_NUM_DIN_CHANNELS);
#endif
	DIO_configureIn(HAL_SObj.inPortHandles[aChannel], aResourceNumber);
}

AIN_AdcParams_t* HAL_getDefaultAdcParams()
{
	AIN_setDefaultAdcParams(&HAL_SObj.aInParamsMemory);
	return &HAL_SObj.aInParamsMemory;
}

void HAL_setupAdc(uint16_t aHandle, uint16_t aAdc, const AIN_AdcParams_t *aInParams)
{
	AIN_configure(HAL_SObj.aInHandle[aHandle], (enum AIN_UNIT)aAdc, aInParams);
	AIN_resetChannelSetup(HAL_SObj.aInHandle[aHandle]);
}

AIN_ChannelParams_t* HAL_getDefaultAinChannelParams()
{
	AIN_setDefaultChannelParams(&HAL_SObj.aInChannelParamsMemory);
	return &HAL_SObj.aInChannelParamsMemory;
}

void HAL_setupAnalogIn(uint16_t aAdc, uint16_t aChannel, uint16_t aResourceNumber, const AIN_ChannelParams_t *aParams)
{
#if (HAL_NUM_ADCS > 0)
    PLX_ASSERT(aAdc < HAL_NUM_ADCS);
#endif
	PLX_ASSERT(aChannel < HAL_NUM_CHANNELS_PER_ADC);

	AIN_setupChannel(HAL_SObj.aInHandle[aAdc], aChannel, aResourceNumber, aParams);
}

void HAL_setupAnalogInF(uint16_t aAdc, uint16_t aChannel, uint16_t aResourceNumber, const AIN_ChannelParams_t *aParams, float scale, float offset)
{
	HAL_setupAnalogIn(aAdc, aChannel, aResourceNumber, aParams);
	HAL_SObj.aInScale[aAdc][aChannel] = scale;
	HAL_SObj.aInOffset[aAdc][aChannel] = offset;
}

PWM_Params_t* HAL_getDefaultPwmParams(uint16_t aPeriodCounts, uint16_t aDeadtimeCounts, uint16_t aSOCASelect)
{
	PWM_setDefaultParams(&HAL_SObj.pwmParamsMemory);
	HAL_SObj.pwmParamsMemory.TBPRD = aPeriodCounts;
	HAL_SObj.pwmParamsMemory.DBFED.all = aDeadtimeCounts;
	HAL_SObj.pwmParamsMemory.DBRED.all = aDeadtimeCounts;
	return &HAL_SObj.pwmParamsMemory;
}

void HAL_setupPwm(uint16_t aChannel, uint16_t aResourceNumber, const PWM_Params_t *aPwmParams)
{
#if (HAL_NUM_PWM_CHANNELS > 0)
    PLX_ASSERT(aChannel < HAL_NUM_PWM_CHANNELS);
#endif

	PWM_configure(HAL_SObj.pwmHandles[aChannel], aResourceNumber, aPwmParams);
	PWR_registerPwmChannel(HAL_SObj.pwmHandles[aChannel]);
}

QEP_Params_t* HAL_getDefaultQepParams(uint32_t aPeriodCounts, bool aEnableResetByIndexPulse)
{
    QEP_setDefaultParams(&HAL_SObj.qepParamsMemory);
    HAL_SObj.qepParamsMemory.QPOSMAX = aPeriodCounts;
    if(aEnableResetByIndexPulse){
        HAL_SObj.qepParamsMemory.QEPCTL.bit.PCRM = 0; // operate QEP in Reset on index event
    } else {
        HAL_SObj.qepParamsMemory.QEPCTL.bit.PCRM = 1; // operate QEP in Reset on Max counter mode
    }
    return &HAL_SObj.qepParamsMemory;
}
void HAL_setupQep(uint16_t aChannel, uint16_t aResourceNumber, uint16_t aPinSet, QEP_Params_t *aParams)
{
#if (HAL_NUM_QEP_CHANNELS > 0)
    PLX_ASSERT(aChannel < HAL_NUM_QEP_CHANNELS);
#endif
	QEP_configure(HAL_SObj.qepHandles[aChannel], aResourceNumber, aPinSet, aParams);
}

SPI_Params_t* HAL_getDefaultSpiParams(uint16_t aCharLength, bool aPol, bool aPhase, uint32_t aBaudRate, bool aMasterSlave)
{
    HAL_SObj.spiParamsMemory.SPICHAR = aCharLength;
    HAL_SObj.spiParamsMemory.CLKPOLARITY = aPol;
    HAL_SObj.spiParamsMemory.CLKPHASE = aPhase;
    HAL_SObj.spiParamsMemory.BAUDRATE = aBaudRate;
    HAL_SObj.spiParamsMemory.MASTERSLAVE = aMasterSlave;
    return &HAL_SObj.spiParamsMemory;
}

void HAL_setupSpi(uint16_t aChannel, uint16_t aResourceNumber, uint16_t aPinSet, SPI_Params_t *aParams)
{
#if (HAL_NUM_SPI_CHANNELS > 0)
    PLX_ASSERT(aChannel < HAL_NUM_SPI_CHANNELS);
#endif
	SPI_configure(HAL_SObj.spiHandles[aChannel], aResourceNumber, LSPCLK_HZ);
	SPI_setupPort(HAL_SObj.spiHandles[aChannel], aPinSet, aParams);
}

void HAL_setupPwrTzGpio(uint16_t aTzId, uint16_t aGpio)
{
	PLX_ASSERT(aTzId < HAL_NUM_TZ_CHANNELS);
	PWR_configureTZGpio(aTzId, aGpio);
}

void HAL_setupPwmSyncSelect(uint16_t aResourceNumber, uint16_t aType, uint16_t aUnit)
{
	PWM_configureSyncSel(aResourceNumber, aType, aUnit);
}

