/*
   Copyright (c) 2014-2016 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#ifndef AIN_IMPL_H_
#define AIN_IMPL_H_

#include "f28004x_adc.h"

#define AIN_NUM_CHANNELS 16

typedef enum AIN_UNIT {
	AIN_ADC_A = 0,
	AIN_ADC_B,
	AIN_ADC_C,
	AIN_ADC_D
} AIN_Unit_t;

typedef struct AIN_ADC_PARAMS {
    union ADCINTSEL1N2_REG ADCINTSEL1N2;
	union ADCCTL1_REG ADCCTL1;
	union ADCCTL2_REG ADCCTL2;
	union ADCSOCPRICTL_REG ADCSOCPRICTL;
} AIN_AdcParams_t;

typedef struct AIN_CHANNEL_PARAMS {
	union ADCSOC0CTL_REG  ADCSOCxCTL;
} AIN_ChannelParams_t;

typedef struct AIN_OBJ
{
	volatile struct ADC_REGS *adc;
	union ADCSOC0CTL_REG *socCtrl;
	volatile uint16_t *results;
} AIN_Obj_t;

typedef AIN_Obj_t *AIN_Handle_t;

extern void AIN_getRegisterBase(AIN_Unit_t aAdcUnit, volatile struct ADC_REGS** aReg);

inline uint16_t AIN_getIn(AIN_Handle_t aHandle, uint16_t aChannel)
{
    AIN_Obj_t *obj = (AIN_Obj_t *)aHandle;

    PLX_ASSERT(aChannel < AIN_NUM_CHANNELS);
    return obj->results[aChannel];
}

#endif /* AIN_IMPL_H_ */
