local T = { }

local pwmGpio = {}
pwmGpio[1] = {0,1}
pwmGpio[2] = {2,3}
pwmGpio[3] = {4,5}
pwmGpio[4] = {6,7}
pwmGpio[5] = {8,9}
pwmGpio[6] = {10,11}  

local qepPinset = {}
qepPinset["20-21-23"] = 0
qepPinset["50-51-53"] = 1

local spiPinset = {}
spiPinset["16-17-18-19"] = 10
spiPinset["24-25-26-27"] = 20
spiPinset["24-25-14"] = 21

local sciPinset = {}
sciPinset["28-29"] = 0

function T.Configure(resources, registry)
  resources:add("Model Trigger", 1, 1)  
  resources:add("Powerstage Control", 1, 1)  	
  resources:add("GPIO", 0, 58) 
  resources:add("ADC", 0, 1)   
  resources:add("PWM", 1, 6) 
  resources:add("QEP", 1, 2) 
  resources:add("SPI", 1, 2)	 
  resources:add("ADCA-SOC", 0, 15)
end

function T.GetPwmGpio(unit)
	if pwmGpio[unit]==nil then
	  return -1 -- Error code - resource not available.
	else
	  return pwmGpio[unit]
	end
end

function T.GetSciPinset(pinsetS)
	return sciPinset[pinsetS]
end

function T.GetQepPinset(pinsetS)
	return qepPinset[pinsetS]
end

function T.GetSpiPinset(pinsetS)
	return spiPinset[pinsetS]
end

function T.GetIntOscClock()
	return 10000000 -- INTOSC2
end

function T.GetTimerClock()
    -- to help with margin and latency measurements, timer is configured at rate of PWM
	return T.GetPwmClock()
end

function T.GetPwmClock()
	return Target.Variables.sysClkMHz * 1e6 / 2
end

function T.GetDeadTimeClock()
	return Target.Variables.sysClkMHz * 1e6 / 2
end

function T.GetMaxEventPeriod()
	return 3
end

function T.GetMaxSciBaudRate()
	-- assuming 8N1. 1.5 characters per poll
	local maxRate = 1/Target.Variables.SAMPLE_TIME * 15
	return math.min(115200, maxRate)
end

function T.GetAdcClock()
	-- HAL automatically configures ADCCTL2.bit.PRESCALE
	local sysClkHz = Target.Variables.sysClkMHz * 1e6
	if sysClkHz <= 45000000 then
		return sysClkHz
	else
		return sysClkHz / 2
	end
end

function T.CalcACQPS(ts)
	local tsMin = 7/T.GetAdcClock() -- per datasheet - different
	local tsMax = 64/T.GetAdcClock()
	if ts ~= ts or ts < tsMin then -- test for NAN or value that is too small
		ts = tsMin 
	elseif ts > tsMax then
		ts = tsMax -- maybe we should be less tolerant here and throw an error?
	end
	return math.floor(ts * T.GetAdcClock());
end

function T.GetINTSEL1N2RegisterName()
	return "INTSEL1N2"
end

function T.WriteClockConfiguration(io)
  local sysClkHz = Target.Variables.sysClkMHz * 1e6
  
  if sysClkHz > 90000000 then
    return "Excessive system clock setting."
  end 
  
  if sysClkHz ~= math.floor(sysClkHz) then
    return "System clock setting must be integer value."
  end 

  local clkin, clksrc

  if Target.Variables.useIntOsc ~= 1 then
  	clkin = Target.Variables.extClkMHz * 1e6
  	clksrc = 1
  else
  	clkin =  T.GetIntOscClock()
  	clksrc = 0
  end


  local pllDiv = math.min(math.floor(2*sysClkHz/clkin), 18)
  if not (sysClkHz == pllDiv * clkin/2) then
    return "Unable to achieve the desired system clock frequency (with input clock = %d Hz)." % {clkin}
  end
  
  local cpuRate = 100.0/ sysClkHz * 10000000;
  
  io.write("// Clock configurations\n")
  io.write("#define SYSCLK_HZ %iL\n" % {sysClkHz}) 
  io.write("#define LSPCLK_HZ (SYSCLK_HZ / 4l)\n")
    
  io.write("#define PLL_DIV %i\n" % {pllDiv})
  io.write("#define PLL_SRC " .. clksrc ..  "\n")  
  io.write("#define PLX_CPU_RATE " .. cpuRate .. "L\n")
  io.write("\n")
end

return T
